const Tenor = require('.');
const dotenv = require('dotenv').config();

if (process.env.TENOR_API_KEY === undefined) {
    console.error('Please set TENOR_API_KEY in .env');
    process.exit(1);
}

const tests = [
    // Valid API Key
    new Promise((resolve, reject) => {
        const tenor = new Tenor(process.env.TENOR_API_KEY);
        tenor.configure()
            .then((result) => {
                console.log('PASS: Valid API Key --', result);
                resolve();
            })
            .catch((error) => {
                console.error('FAIL: Valid API Key --', error.message);
                return reject();
            });
    }),
    // Invalid API Key
    new Promise((resolve, reject) => {
        const tenor = new Tenor('invalidApiKey');
        tenor.configure()
            .then((result) => {
                console.log('FAIL: Invalid API Key');
                return reject();
            })
            .catch((error) => {
                console.error('PASS: Invalid API Key --', error.message);
                resolve();
            });
    }),
    // Valid query and limit
    new Promise((resolve, reject) => {
        const tenor = new Tenor(process.env.TENOR_API_KEY);
        // Form the options for the search
        const options = {
            limit: 5
        };

        if (process.env.TENOR_CLIENT_KEY) {
            options.clientKey = process.env.TENOR_CLIENT_KEY;
        }
        tenor.search('dog', options)
        .then((gifs) => {
            if (Array.isArray(gifs) && gifs.length === 5) {
                console.log('PASS: valid query and limit --', gifs); // Expected output: Array of five Gif objects
                resolve();
            } else {
                console.error('FAIL: valid query and limit --', 'Unexpected response format'); // Show only the FAIL message
                return reject();
            }
        })
        .catch((error) => {
            console.error('FAIL: valid query and limit --', error.message); // Show only the FAIL message
            return reject();
        });
    })
];

Promise.all(tests)
    .then(() => {
        console.log('All tests passed!');
        process.exit(0);
    })
    .catch(() => {
        console.log('Some tests failed!');
        process.exit(1);
    });
